==> haskell-chell-0.5-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-chell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chell
version: 0.5
id: chell-0.5-9UWUMeehunf2H8z3P3Mj4g
key: chell-0.5-9UWUMeehunf2H8z3P3Mj4g
license: MIT
maintainer: Chris Martin, Julie Moronuki
author: John Millikin <john@john-millikin.com>
homepage: https://github.com/typeclasses/chell
synopsis: A simple and intuitive library for automated testing.
description:
    Chell is a simple and intuitive library for automated testing. It natively
    supports assertion-based testing, and can use companion libraries
    such as @chell-quickcheck@ to support more complex testing strategies.
    .
    An example test suite, which verifies the behavior of artithmetic operators.
    .
    @
    &#x7b;-\# LANGUAGE TemplateHaskell \#-&#x7d;
    .
    import Test.Chell
    .
    tests_Math :: Suite
    tests_Math = suite \"math\"
    &#x20;   [ test_Addition
    &#x20;   , test_Subtraction
    &#x20;   ]
    .
    test_Addition :: Test
    test_Addition = assertions \"addition\" $ do
    &#x20;   $expect (equal (2 + 1) 3)
    &#x20;   $expect (equal (1 + 2) 3)
    .
    test_Subtraction :: Test
    test_Subtraction = assertions \"subtraction\" $ do
    &#x20;   $expect (equal (2 - 1) 1)
    &#x20;   $expect (equal (1 - 2) (-1))
    .
    main :: IO ()
    main = defaultMain [tests_Math]
    @
    .
    @
    $ ghc --make chell-example.hs
    $ ./chell-example
    PASS: 2 tests run, 2 tests passed
    @
category: Testing
abi: cc5d82a5af40ad0a486d5a1b7d2a242c
exposed: True
exposed-modules:
    Test.Chell
hidden-modules: Test.Chell.Main Test.Chell.Output Test.Chell.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/chell-0.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/chell-0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/chell-0.5
hs-libraries: HSchell-0.5-9UWUMeehunf2H8z3P3Mj4g
depends:
    ansi-terminal-0.8.2-IytGdmUG1lK1dAjqEeG5cq base-4.12.0.0
    bytestring-0.10.8.2 options-1.2.1.1-FMpEp48m7Zu8qqR2BW81vr
    patience-0.2.1.1-Ac4ITT3UjP43CS8LmqYmVB
    random-1.1-3ypV4EIycgb35PKjTYYr5q template-haskell-2.14.0.0
    text-1.2.3.1 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-chell/html/chell.haddock
haddock-html: /usr/share/doc/haskell-chell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chell-0.5-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-chell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chell
version: 0.5
id: chell-0.5-HBBVh0kuv2x5hKcNiXPL5Z
key: chell-0.5-HBBVh0kuv2x5hKcNiXPL5Z
license: MIT
maintainer: Chris Martin, Julie Moronuki
author: John Millikin <john@john-millikin.com>
homepage: https://github.com/typeclasses/chell
synopsis: A simple and intuitive library for automated testing.
description:
    Chell is a simple and intuitive library for automated testing. It natively
    supports assertion-based testing, and can use companion libraries
    such as @chell-quickcheck@ to support more complex testing strategies.
    .
    An example test suite, which verifies the behavior of artithmetic operators.
    .
    @
    &#x7b;-\# LANGUAGE TemplateHaskell \#-&#x7d;
    .
    import Test.Chell
    .
    tests_Math :: Suite
    tests_Math = suite \"math\"
    &#x20;   [ test_Addition
    &#x20;   , test_Subtraction
    &#x20;   ]
    .
    test_Addition :: Test
    test_Addition = assertions \"addition\" $ do
    &#x20;   $expect (equal (2 + 1) 3)
    &#x20;   $expect (equal (1 + 2) 3)
    .
    test_Subtraction :: Test
    test_Subtraction = assertions \"subtraction\" $ do
    &#x20;   $expect (equal (2 - 1) 1)
    &#x20;   $expect (equal (1 - 2) (-1))
    .
    main :: IO ()
    main = defaultMain [tests_Math]
    @
    .
    @
    $ ghc --make chell-example.hs
    $ ./chell-example
    PASS: 2 tests run, 2 tests passed
    @
category: Testing
abi: 3b28a076c8b59549d45a49588b1be553
exposed: True
exposed-modules:
    Test.Chell
hidden-modules: Test.Chell.Main Test.Chell.Output Test.Chell.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/chell-0.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/chell-0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/chell-0.5
hs-libraries: HSchell-0.5-HBBVh0kuv2x5hKcNiXPL5Z
depends:
    ansi-terminal-0.8.2-LbawE0xYmiu2QkRGz1IZXL base-4.12.0.0
    bytestring-0.10.8.2 options-1.2.1.1-FMpEp48m7Zu8qqR2BW81vr
    patience-0.2.1.1-Ac4ITT3UjP43CS8LmqYmVB
    random-1.1-3ypV4EIycgb35PKjTYYr5q template-haskell-2.14.0.0
    text-1.2.3.1 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-chell/html/chell.haddock
haddock-html: /usr/share/doc/haskell-chell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
